@@ -22,6 +22,9 @@ class ConfigOptions(metaclass=ConfigMeta):
     #: Pause in seconds between starting new jobs in Control Loop
     JOB_SERVICE_PAUSE_BETWEEN_JOBS: str = "5"
 
+    #: Port for which Prometheus metric server will be running on
+    JOB_SERVICE_PROMETHEUS_METRIC_PORT: int = 8080
+
     #: Default timeout when running batch ingestion
     BATCH_INGESTION_PRODUCTION_TIMEOUT: str = "120"
 
@@ -114,6 +117,9 @@ class ConfigOptions(metaclass=ConfigMeta):
     #: Default Redis port
     REDIS_PORT: Optional[str] = ""
 
+    #: Redis credentials
+    REDIS_PASSWORD: Optional[str] = ""
+
     #: Enable or disable TLS/SSL to Redis
     REDIS_SSL: Optional[str] = "False"
 
@@ -166,6 +172,9 @@ class ConfigOptions(metaclass=ConfigMeta):
     #: Log path of EMR cluster
     EMR_LOG_LOCATION: Optional[str] = None
 
+    #: Whitelisted Feast Job Types
+    WHITELISTED_JOB_TYPES: Optional[str] = None
+
     #: Whitelisted Feast projects
     WHITELISTED_PROJECTS: Optional[str] = None
 
